@@ -15,8 +15,8 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('-c', '--config', default='config.json', help='dotfiles configuration. Points to target locations.')
     parser.add_argument('-w', '--config_dir', default='.', help='Location of the configuration files to sync')
-    parser.add_argument('-d', '--dry', action='store_true', default=False)
-    parser.add_argument('-i', '--interactive', action='store_true', default=False)
+    parser.add_argument('-d', '--dry', action='store_true', default=False, help='Never actually write any files, only read and show me what you would have done')
+    parser.add_argument('-i', '--interactive', action='store_true', default=False, help='Before doing a write, ask for confirmation')
 
     sub_parsers = parser.add_subparsers(dest='command')
     dotfiles.subcommands.list.add_sub_parser(sub_parsers)
